SystemOrganization addCategory: #ConfigurationOfKendrick!

Object subclass: #ConfigurationOfKendrick
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfKendrick'!

!ConfigurationOfKendrick commentStamp: 'SergeStinckwich 7/21/2014 14:58' prior: 0!
ConfigurationOfKendrick is a Metacello Configuration to load the packages of the Kendrick project.

Kendrick is a Domain-Specific Language and Simulation Plaform for mathematical epidemiology modeling. All the development happens on SmalltalkHub at the moment: http://bit.ly/XrpsL2

Kendrick is based extensively on several tools of the meta-modeling platform MOOSE including PetitParser and Graph-ET.

Github is only used to to store the issues list: https://github.com/UMMISCO/Kendrick/issues?state=open!

!ConfigurationOfKendrick class methodsFor: 'development support' stamp: 'SergeStinckwich 3/14/2014 15:43'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfKendrick class methodsFor: 'private' stamp: 'SergeStinckwich 3/14/2014 15:43'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfKendrick class methodsFor: 'private' stamp: 'SergeStinckwich 3/14/2014 15:43'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfKendrick class methodsFor: 'private' stamp: 'SergeStinckwich 3/14/2014 15:43'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfKendrick class methodsFor: 'metacello tool support' stamp: 'SergeStinckwich 3/14/2014 15:43'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfKendrick class methodsFor: 'loading' stamp: 'SergeStinckwich 3/14/2014 15:43'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfKendrick class methodsFor: 'loading' stamp: 'SergeStinckwich 3/14/2014 15:43'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfKendrick class methodsFor: 'loading' stamp: 'SergeStinckwich 3/14/2014 15:43'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfKendrick class methodsFor: 'accessing' stamp: 'SergeStinckwich 3/14/2014 15:43'!
project

	^self new project! !

!ConfigurationOfKendrick class methodsFor: 'development support' stamp: 'SergeStinckwich 3/14/2014 15:43'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfKendrick methodsFor: 'baselines' stamp: 'SergeStinckwich 3/17/2014 19:39'!
baseline01: spec
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/UMMISCO/Kendrick/main/'.
		spec 
			project: 'Fame' with: [
				spec
					className: #ConfigurationOfFame;
					versionString: 'bleedingEdge';
					repository: 'http://smalltalkhub.com/mc/Moose/Fame/main/' ];
			project: 'GraphET' with: [
				spec
					className: #ConfigurationOfGraphET;
					versionString: 'stable';
					repository: 'http://smalltalkhub.com/mc/ObjectProfile/GraphET/main/' ].
		spec package: 'Kendrick'. ].
! !

!ConfigurationOfKendrick methodsFor: 'baselines' stamp: 'SergeStinckwich 4/15/2014 15:06'!
baseline02: spec
	<version: '0.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/UMMISCO/Kendrick/main/'.
		spec project: 'Moose' with: [
				spec
					className: #ConfigurationOfMoose;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/Moose/Moose/main/' ].
		spec package: 'Kendrick'. ].
! !

!ConfigurationOfKendrick methodsFor: 'baselines' stamp: 'SergeStinckwich 4/16/2014 16:22'!
baseline03: spec
	<version: '0.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/UMMISCO/Kendrick/main/'.
		spec project: 'Moose' with: [
				spec
					className: #ConfigurationOfMoose;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/Moose/Moose/main/' ].
		spec project: 'SciSmalltalk' with: [
				spec
					className: #ConfigurationOfSciSmalltalk;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/SergeStinckwich/SciSmalltalk/main/' ].
		spec 
			package: 'Kendrick'].
! !

!ConfigurationOfKendrick methodsFor: 'accessing' stamp: 'SergeStinckwich 3/14/2014 15:43'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfKendrick methodsFor: 'symbolic versions' stamp: 'SergeStinckwich 4/16/2014 14:34'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.3-baseline'.
! !

!ConfigurationOfKendrick methodsFor: 'accessing' stamp: 'SergeStinckwich 3/14/2014 15:43'!
project

	^ project ifNil: [ 
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfKendrick methodsFor: 'symbolic versions' stamp: 'SergeStinckwich 9/22/2014 12:29'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '0.10'
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 9/22/2014 14:38'!
version010: spec
	<version: '0.10' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.10 - All green tests'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '9/22/2014 12:30'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.14'.
		spec package: 'Kendrick' with: 'Kendrick-BUIThiMaiAnh.272']
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 3/17/2014 19:39'!
version01: spec
	<version: '0.1' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.1'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '3/17/2014 19:39'.
		spec 
			project: 'Fame' with: '1.4-snapshot';
			project: 'GraphET' with: '0.3-snapshot'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.187'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 4/15/2014 15:26'!
version02: spec
	<version: '0.2' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.2'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '4/15/2014 15:25'.
		spec project: 'Moose' with: '5.0-baseline'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.187'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 4/16/2014 16:22'!
version03: spec
	<version: '0.3' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.3'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '4/16/2014 14:34'.
		spec project: 'Moose' with: '5.0-baseline'.
		spec project: 'SciSmalltalk' with: '0.8'.
		spec 
			package: 'Kendrick' with: 'Kendrick-SergeStinckwich.187' ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 4/16/2014 17:01'!
version04: spec
	<version: '0.4' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.4'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '4/16/2014 17:01'.
		spec project: 'Moose' with: '5.0-baseline'.
		spec project: 'SciSmalltalk' with: '0.9'.
		spec 
			package: 'Kendrick' with: 'Kendrick-SergeStinckwich.187' ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 4/25/2014 00:24'!
version05: spec
	<version: '0.5' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.5'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '4/25/2014 00:16'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.9'.
		spec package: 'Kendrick' with: 'Kendrick-FabriceATREVI.189'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 6/18/2014 17:25'!
version06: spec
	<version: '0.6' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.6'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '6/17/2014 00:16'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.9'.
		spec package: 'Kendrick' with: 'Kendrick-ATREVIFabrice.196'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 6/18/2014 17:24'!
version07: spec
	<version: '0.7' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.7'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '6/18/2014 00:16'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.9'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.197'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 9/19/2014 13:17'!
version08: spec
	<version: '0.8' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.8'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '7/24/2014 16:33'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.12'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.197']
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 9/19/2014 13:17'!
version09: spec
	<version: '0.9' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.9'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '9/19/2014 13:16'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.14'.
		spec package: 'Kendrick' with: 'Kendrick-BuiThiMaiAnh.269']
! !
